==> chainwallet-1.0.2.tar.gz: lib/src/core/serialized/enums/TransactionType.dart <==

import 'dart:typed_data';

import "../SerializedType.dart";


import 'package:chainwallet/src/utils/Util.dart';
import 'package:chainwallet/src/core/fields/Type.dart';
import 'package:chainwallet/src/core/serialized/BytesSink.dart';
import 'package:chainwallet/src/core/serialized/TypeTranslator.dart';
import 'package:chainwallet/src/core/serialized/BinaryParser.dart';
class TransactionType extends SerializedType {

  static final Invalid = new TransactionType(-1);
  static final Payment = new TransactionType(0);
  static final TrustSet = new TransactionType(20);
  static final SQLStatement = new TransactionType(22);
  final int ord;


  static TransactionTypeTranslator translate = new TransactionTypeTranslator();

  TransactionType(int i) :ord = i{

  }

  static Map<int ,TransactionType> _byCode = new Map<int,TransactionType>();
  static bool _bInit = false;

  static TransactionType fromNumber(int integer){

    if(!_bInit){
      _byCode[-1]  = TransactionType.Invalid;
      _byCode[0]   = TransactionType.Payment;
      _byCode[20]  = TransactionType.TrustSet;
      _byCode[22]  = TransactionType.SQLStatement;
      _bInit = true;
    }

    return _byCode[integer];
  }

  Map toJSON() => null;

  static TransactionType valueOf(String name){
    switch(name){
      case "Payment":
        return Payment;
      case "TrustSet":
        return TrustSet;
      case "SQLStatement":
        return SQLStatement;
      default:
        return Invalid;
    }
  }


  Uint8List toBytes() => Uint8List.fromList([ord >> 8,ord & 0xFF]);


  String toHex() => Util.formatBytesAsHexString(toBytes());

  void toBytesSink(BytesSink to) => to.addBytes(toBytes());

  Type type() => Type.UInt16;




//  static final Generic = new Field(0, Type.Unknown);
////
////  static final TransactionType = new Field(2, Type.UInt16);
////
////  static final Sequence = new Field(4, Type.UInt32);
////
////  static final Amount = new Field(1, Type.Amount);
////  static final Fee = new Field(8, Type.Amount);
////
////  static final Account     = new Field(1, Type.AccountID);
////  static final Destination = new Field(3, Type.AccountID);

}


class TransactionTypeTranslator extends TypeTranslator<TransactionType> {

  TransactionType fromParser(BinaryParser parser, int hint){
    Uint8List read = parser.read(2);
    return TransactionType.fromNumber((read[0] << 8) | read[1]);
  }


  TransactionType fromInteger(int integer) {
    return TransactionType.fromNumber(integer);
  }


  TransactionType fromString(String value) {
    return TransactionType.valueOf(value);
  }
}

==> chainwallet-1.0.4.tar.gz: lib/src/core/serialized/enums/TransactionType.dart <==
import 'dart:typed_data';

import "../SerializedType.dart";

import 'package:chainwallet/src/utils/Util.dart';
import 'package:chainwallet/src/core/fields/Type.dart';
import 'package:chainwallet/src/core/serialized/BytesSink.dart';
import 'package:chainwallet/src/core/serialized/TypeTranslator.dart';
import 'package:chainwallet/src/core/serialized/BinaryParser.dart';

class TransactionType extends SerializedType {
  static final Invalid = new TransactionType(-1);
  static final Payment = new TransactionType(0);
  static final TrustSet = new TransactionType(20);
  static final SQLStatement = new TransactionType(22);
  final int ord;

  static TransactionTypeTranslator translate = new TransactionTypeTranslator();

  TransactionType(int i) : ord = i {}

  static Map<int, TransactionType> _byCode = new Map<int, TransactionType>();
  static bool _bInit = false;

  static TransactionType fromNumber(int integer) {
    if (!_bInit) {
      _byCode[-1] = TransactionType.Invalid;
      _byCode[0] = TransactionType.Payment;
      _byCode[20] = TransactionType.TrustSet;
      _byCode[22] = TransactionType.SQLStatement;
      _bInit = true;
    }

    return _byCode[integer];
  }

  Map toJSON() => null;

  static TransactionType valueOf(String name) {
    switch (name) {
      case "Payment":
        return Payment;
      case "TrustSet":
        return TrustSet;
      case "SQLStatement":
        return SQLStatement;
      default:
        return Invalid;
    }
  }

  Uint8List toBytes() => Uint8List.fromList([ord >> 8, ord & 0xFF]);

  String toHex() => Util.formatBytesAsHexString(toBytes());

  void toBytesSink(BytesSink to) => to.addBytes(toBytes());

  Type type() => Type.UInt16;

//  static final Generic = new Field(0, Type.Unknown);
////
////  static final TransactionType = new Field(2, Type.UInt16);
////
////  static final Sequence = new Field(4, Type.UInt32);
////
////  static final Amount = new Field(1, Type.Amount);
////  static final Fee = new Field(8, Type.Amount);
////
////  static final Account     = new Field(1, Type.AccountID);
////  static final Destination = new Field(3, Type.AccountID);

}

class TransactionTypeTranslator extends TypeTranslator<TransactionType> {
  TransactionType fromParser(BinaryParser parser, int hint) {
    Uint8List read = parser.read(2);
    return TransactionType.fromNumber((read[0] << 8) | read[1]);
  }

  TransactionType fromInteger(int integer) {
    return TransactionType.fromNumber(integer);
  }

  TransactionType fromString(String value) {
    return TransactionType.valueOf(value);
  }
}
